@@ -115,6 +115,8 @@ impl<'a, 'b, T: Aabb, N: NodeHandler> CollVis<'a, 'b, T, N> {
                         is_left: bool,
                     ) {
                         let anchor_axis = self.anchor.axis;
+                        let current_is_leaf = m.get_height() == 1;
+
                         let (mut nn, rest) = m.next();
 
                         let current = NodeAxis {
@@ -122,12 +124,15 @@ impl<'a, 'b, T: Aabb, N: NodeHandler> CollVis<'a, 'b, T, N> {
                             axis: this_axis,
                         };
 
+                        //if let Some(_)= current.node.div{
                         self.handler.handle_children(
                             self.sweeper,
                             self.prevec,
                             self.anchor.borrow_mut(),
                             current,
+                            current_is_leaf,
                         );
+                        //};
 
                         if let Some([left, right]) = rest {
                             if let Some(div) = nn.div {
@@ -170,7 +175,7 @@ impl<'a, 'b, T: Aabb, N: NodeHandler> CollVis<'a, 'b, T, N> {
                     }
                 }
 
-                {
+                if nn.div.is_some() {
                     let mut g = InnerRecurser {
                         anchor: NodeAxis {
                             node: nn,
@@ -289,6 +294,7 @@ pub trait NodeHandler: Copy + Clone + Send + Sync {
         prevec: &mut PreVec,
         anchor: NodeAxis<T, A>,
         current: NodeAxis<T, B>,
+        current_is_leaf: bool,
     );
 }
 
@@ -297,15 +303,23 @@ impl NodeHandler for crate::tree::build::NoSorter {
         self,
         func: &mut impl CollisionHandler<T>,
         _: &mut PreVec,
-        _axis: impl Axis,
+        axis: impl Axis,
         bots: AabbPin<&mut [T]>,
-        _is_leaf: bool,
+        is_leaf: bool,
     ) {
-        queries::for_every_pair(bots, move |a, b| {
-            if a.get().intersects_rect(b.get()) {
-                func.collide(a, b);
-            }
-        });
+        if !is_leaf {
+            queries::for_every_pair(bots, move |a, b| {
+                if a.get().get_range(axis).intersects(b.get().get_range(axis)) {
+                    func.collide(a, b);
+                }
+            });
+        } else {
+            queries::for_every_pair(bots, move |a, b| {
+                if a.get().intersects_rect(b.get()) {
+                    func.collide(a, b);
+                }
+            });
+        }
     }
 
     fn handle_children<A: Axis, B: Axis, T: Aabb>(
@@ -314,6 +328,7 @@ impl NodeHandler for crate::tree::build::NoSorter {
         _: &mut PreVec,
         mut anchor: NodeAxis<T, A>,
         current: NodeAxis<T, B>,
+        _current_is_leaf: bool,
     ) {
         let res = if !current.axis.is_equal_to(anchor.axis) {
             true
@@ -344,8 +359,8 @@ impl NodeHandler for crate::tree::build::DefaultSorter {
         is_leaf: bool,
     ) {
         //
-        // All bots belonging to a non leaf node are guarenteed to touch the divider.
-        // Therfore, all bots intersect along one axis already. Because:
+        // All bots belonging to a non leaf node are guaranteed to touch the divider.
+        // Therefore, all bots intersect along one axis already. Because:
         //
         // If a contains x and b contains x then a intersects b.
         //
@@ -358,39 +373,116 @@ impl NodeHandler for crate::tree::build::DefaultSorter {
         prevec: &mut PreVec,
         mut anchor: NodeAxis<T, A>,
         current: NodeAxis<T, B>,
+        current_is_leaf: bool,
     ) {
         if !current.axis.is_equal_to(anchor.axis) {
             let cc1 = &anchor.node.cont;
+            let div = anchor.node.div.unwrap();
 
             let cc2 = current.node.into_node_ref();
 
             let r1 = super::tools::get_section_mut(anchor.axis, cc2.range, cc1);
 
-            let r2 = super::tools::get_section_mut(
+            let mut r2 = super::tools::get_section_mut(
                 current.axis,
                 anchor.node.borrow_mut().into_range(),
                 cc2.cont,
             );
 
-            oned::find_perp_2d1(prevec, current.axis, r1, r2, func);
-        } else if current.node.cont.intersects(&anchor.node.cont) {
-            /*
-            oned::find_parallel_2d(
-                &mut self.prevec1,
-                current.axis.next(),
-                current.node.into_range(),
-                anchor.node.borrow_mut().into_range(),
-                func,
-            );
-            */
+            let axis = current.axis.next();
 
-            oned::find_parallel_2d(
-                prevec,
-                current.axis.next(),
-                anchor.node.borrow_mut().into_range(),
-                current.node.into_range(),
-                func,
-            );
+            //iterate over current nodes botd
+            for y in r1.iter_mut() {
+                let r2 = r2.borrow_mut();
+
+                match y.get().get_range(axis).contains_ext(div) {
+                    std::cmp::Ordering::Equal => {
+                        oned::find_perp_2d1_once(prevec, current.axis, y, r2, |a, b| {
+                            func.collide(a, b)
+                        });
+                    }
+                    std::cmp::Ordering::Greater => {
+                        oned::find_perp_2d1_once(prevec, current.axis, y, r2, |a, b| {
+                            if a.get().get_range(axis).end >= b.get().get_range(axis).start {
+                                func.collide(a, b);
+                            }
+                        });
+                    }
+                    std::cmp::Ordering::Less => {
+                        oned::find_perp_2d1_once(prevec, current.axis, y, r2, |a, b| {
+                            //if a.get().get_range(axis).intersects(b.get().get_range(axis)) {
+                            if a.get().get_range(axis).start <= b.get().get_range(axis).end {
+                                func.collide(a, b);
+                            }
+                        });
+                    }
+                }
+
+                /*
+                oned::find_perp_2d1_once(prevec,current.axis,y,r2,|a,b|{
+                    if a.get().get_range(axis).intersects(b.get().get_range(axis)) {
+                    //if a.get().get_range(axis).start<=b.get().get_range(axis).end{
+                        func.collide(a,b);
+                    }
+                });
+                */
+            }
+        } else {
+            let axis = anchor.axis;
+
+            let anchor_div = anchor.node.div.unwrap();
+
+            if current_is_leaf {
+                oned::find_parallel_2d(
+                    prevec,
+                    current.axis.next(),
+                    anchor.node.borrow_mut().into_range(),
+                    current.node.into_range(),
+                    |a, b| {
+                        if a.get().get_range(axis).intersects(b.get().get_range(axis)) {
+                            func.collide(a, b)
+                        }
+                    },
+                );
+            } else if let Some(current_div) = current.node.div {
+                if anchor_div < current_div {
+                    if anchor.node.cont.end >= current.node.cont.start {
+                        oned::find_parallel_2d(
+                            prevec,
+                            current.axis.next(),
+                            anchor.node.borrow_mut().into_range(),
+                            current.node.into_range(),
+                            |a, b| {
+                                if a.get().get_range(axis).end >= b.get().get_range(axis).start {
+                                    func.collide(a, b)
+                                }
+                            },
+                        );
+                    }
+                } else if anchor_div > current_div {
+                    if anchor.node.cont.start <= current.node.cont.end {
+                        oned::find_parallel_2d(
+                            prevec,
+                            current.axis.next(),
+                            anchor.node.borrow_mut().into_range(),
+                            current.node.into_range(),
+                            |a, b| {
+                                if a.get().get_range(axis).start <= b.get().get_range(axis).end {
+                                    func.collide(a, b)
+                                }
+                            },
+                        );
+                    }
+                } else {
+                    oned::find_parallel_2d(
+                        prevec,
+                        current.axis.next(),
+                        anchor.node.borrow_mut().into_range(),
+                        current.node.into_range(),
+                        |a, b| func.collide(a, b),
+                    );
+                }
+            }
         }
     }
 }
